
.. _algorithms/index:

Algorithms
**********

.. currentmodule:: jgrapht.algorithms

The JGraphT contains a large collection of advanced algorithms.

.. toctree::
   :maxdepth: 2

   connectivity
   shortestpaths
   spanning
   cycles
   coloring
   clustering
   scoring
   planar
   cuts
   flow
   drawing
   isomorphism
   tour
   cliques
   independent
   vertexcover
   
